==> nnhl-0.1.2.tar.gz: nnhl-0.1.2/src/MainWin.h <==
//----------------------------------------------------//
// Wide Studio Application C++ Source File            //
//            created by Wide Studio source generator //
//----------------------------------------------------//
#ifndef _MainWin_H
#define _MainWin_H
#include <WScom.h>
#include <WSDappDev.h>

//--- OBJECT includes ---//
#include <WSCmainWindow.h>
#include <WSCvkslabel.h>
#include <WSCvtimer.h>
#include <WSCvscrBar.h>
#include <WSCcomboBox.h>
#include <WSCvbtn.h>
#include <WSCvlabel.h>
#include <WSCmenuArea.h>
#include <WSCpulldownMenu.h>
#include <WSCdialog.h>
#include <WSCvifield.h>
#include <WSCvtoggle.h>

//--- OBJECT instance variable ---//
extern WSCmainWindow* MainWin;
extern WSCvkslabel* Maivksl_HeadLine;
extern WSCvtimer* Maivtim_MainTimer;
extern WSCvtimer* Maivtim_BeginTimer;
extern WSCvscrBar* Maivscr_ScrollBar;
extern WSCcomboBox* Maicomb_NameList;
extern WSCvbtn* Maivbtn_StopBtn;
extern WSCvbtn* Maivbtn_NextUrlBtn;
extern WSCvbtn* Maivbtn_PrevUrlBtn;
extern WSCvbtn* Maivbtn_NextArtBtn;
extern WSCvbtn* Maivbtn_PrevArtBtn;
extern WSCvlabel* Maivlab_Art;
extern WSCvlabel* Maivlab_Thr;
extern WSCvbtn* Maivbtn_NextThrBtn;
extern WSCvbtn* Maivbtn_PrevThrBtn;
extern WSCvlabel* Maivlab_Site;
extern WSCvbtn* Maivbtn_BarBtn;
extern WSCvtimer* Maivtim_UpdateTimer;
extern WSCmenuArea* Maimenu_000;
extern WSCpulldownMenu* Maipull_MainMenuFile;
extern WSCpulldownMenu* Maipull_MainMenuOpt;
extern WSCdialog* Cnfdial_ConfigUrl;
extern WSCvbtn* Cnfvbtn_NewBtn;
extern WSCvbtn* Cnfvbtn_UpdateBtn;
extern WSCvifield* Cnfvifi_Name;
extern WSCvifield* Cnfvifi_Url;
extern WSCvlabel* Cnfvlab_Name;
extern WSCvlabel* Cnfvlab_Url;
extern WSCvtoggle* Cnfvtog_Download;
extern WSCvbtn* Cnfvbtn_DeleteBtn;
extern WSCcomboBox* Cnfcomb_NameList;
extern WSCcomboBox* Cnfcomb_Encoding;
extern WSCvlabel* Cnfvlab_Encoding;

#endif /* _MainWin_H */

==> nnhl-0.1.3.tar.gz: nnhl-0.1.3/src/MainWin.h <==
//----------------------------------------------------//
// Wide Studio Application C++ Source File            //
//            created by Wide Studio source generator //
//----------------------------------------------------//
#ifndef _MainWin_H
#define _MainWin_H
#include <WScom.h>
#include <WSDappDev.h>

//--- OBJECT includes ---//
#include <WSCmainWindow.h>
#include <WSCvkslabel.h>
#include <WSCvtimer.h>
#include <WSCvscrBar.h>
#include <WSCcomboBox.h>
#include <WSCvbtn.h>
#include <WSCvlabel.h>
#include <WSCmenuArea.h>
#include <WSCpulldownMenu.h>
#include <WSCdialog.h>
#include <WSCvifield.h>
#include <WSCvtoggle.h>
#include <WSCvslider.h>

//--- OBJECT instance variable ---//
extern WSCmainWindow* MainWin;
extern WSCvkslabel* Maivksl_HeadLine;
extern WSCvtimer* Maivtim_MainTimer;
extern WSCvtimer* Maivtim_BeginTimer;
extern WSCvscrBar* Maivscr_ScrollBar;
extern WSCcomboBox* Maicomb_NameList;
extern WSCvbtn* Maivbtn_StopBtn;
extern WSCvbtn* Maivbtn_NextUrlBtn;
extern WSCvbtn* Maivbtn_PrevUrlBtn;
extern WSCvbtn* Maivbtn_NextArtBtn;
extern WSCvbtn* Maivbtn_PrevArtBtn;
extern WSCvlabel* Maivlab_Art;
extern WSCvlabel* Maivlab_Thr;
extern WSCvbtn* Maivbtn_NextThrBtn;
extern WSCvbtn* Maivbtn_PrevThrBtn;
extern WSCvlabel* Maivlab_Site;
extern WSCvbtn* Maivbtn_BarBtn;
extern WSCvtimer* Maivtim_UpdateTimer;
extern WSCmenuArea* Maimenu_MainMenu;
extern WSCpulldownMenu* Maipull_MainMenuFile;
extern WSCpulldownMenu* Maipull_MainMenuOpt;
extern WSCdialog* Cnfdial_ConfigUrl;
extern WSCvbtn* Cnfvbtn_NewBtn;
extern WSCvbtn* Cnfvbtn_UpdateBtn;
extern WSCvifield* Cnfvifi_Name;
extern WSCvifield* Cnfvifi_Url;
extern WSCvlabel* Cnfvlab_Name;
extern WSCvlabel* Cnfvlab_Url;
extern WSCvtoggle* Cnfvtog_Download;
extern WSCvbtn* Cnfvbtn_DeleteBtn;
extern WSCcomboBox* Cnfcomb_NameList;
extern WSCcomboBox* Cnfcomb_Encoding;
extern WSCvlabel* Cnfvlab_Encoding;
extern WSCvlabel* Cnfvlab_OrderTitle;
extern WSCvlabel* Cnfvlab_Order;
extern WSCvbtn* Cnfvbtn_UpBtn;
extern WSCvbtn* Cnfvbtn_DownBtn;
extern WSCvbtn* Cnfvbtn_TopBtn;
extern WSCvbtn* Cnfvbtn_BottomBtn;
extern WSCvlabel* Cnfvlab_SkipArt;
extern WSCvslider* Cnfvsli_SkipArt;
extern WSCvifield* Cnfvifi_SkipArt;
extern WSCvtimer* Maivtim_ReloadTimer;

#endif /* _MainWin_H */
